myboxplot: The box plot value This function provides a discription of...

Description Usage Arguments Value Examples

View source: R/myboxplot.R

Description

The box plot value This function provides a discription of the box plot.

Usage

1

Arguments

x

vector of sample data from population 1

Value

This function returns a list of 6 components: n: the number of observation the boxplot is drawn with

conf: upper/lower extremes of the notch, out-value of the outliers

group: a vector of the same length that indicate to which group the outlier belongs to.

names: a vector of names for the groups.

Examples

1
 x = rnorm(30,10,12); myboxplot (x)

ElahehJafarigol/Statpackage documentation built on May 10, 2020, 1:45 a.m.