mydata: A function for descriptive statistics The first step after...

Description Usage Arguments Value Examples

View source: R/mydata.R

Description

A function for descriptive statistics The first step after creating the data or reading data from an csv file is descriptive analysis. This function provides the user with information such as mean, standard deviation, and etc. x = rnorm (n, mean, sd) y = rnorm (m, mean, sd)

Usage

1
mydata(x)

Arguments

x

vector of sample data from the population

Value

The function returns mean,median,25th and 75th quartiles,min,max

Examples

1
mydata(x = rnorm (20,5,10))

ElahehJafarigol/Statpackage documentation built on May 10, 2020, 1:45 a.m.