myviolinplot: A function to create a violin plot to compare the two samples

Description Usage Arguments Value Examples

View source: R/myviolinplot.R

Description

A function to create a violin plot to compare the two samples

Usage

1

Arguments

x

: vector of sample data from population 1

y

: vector of sample data from population 2

Value

A violin

Examples

1
x = rnorm(30,10,12); y = rnorm(40,20,15); myviolinplot(x,y)

ElahehJafarigol/Statpackage documentation built on May 10, 2020, 1:45 a.m.