Description Usage Arguments Value Examples
The box plot value This function provides a discription of the box plot.
1 | myboxplot(x)
|
x |
vector of sample data from population 1 |
This function returns a list of 6 components: n: the number of observation the boxplot is drawn with
conf: upper/lower extremes of the notch, out-value of the outliers
group: a vector of the same length that indicate to which group the outlier belongs to.
names: a vector of names for the groups.
1 | x = rnorm(30,10,12); myboxplot (x)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.