Description Usage Arguments Value Examples
A function for descriptive statistics The first step after creating the data or reading data from an csv file is descriptive analysis. This function provides the user with information such as mean, standard deviation, and etc. x = rnorm (n, mean, sd) y = rnorm (m, mean, sd)
1 | mydata(x)
|
x |
vector of sample data from the population |
The function returns mean,median,25th and 75th quartiles,min,max
1 | mydata(x = rnorm (20,5,10))
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.